# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["BrandIdentityStatus"]

BrandIdentityStatus: TypeAlias = Literal["VERIFIED", "UNVERIFIED", "SELF_DECLARED", "VETTED_VERIFIED"]
