# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["AnchorsiteOverride"]

AnchorsiteOverride: TypeAlias = Literal[
    "Latency",
    "Chicago, IL",
    "Ashburn, VA",
    "San Jose, CA",
    "Sydney, Australia",
    "Amsterdam, Netherlands",
    "London, UK",
    "Toronto, Canada",
    "Vancouver, Canada",
    "Frankfurt, Germany",
]
