# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ActionAcceptSuggestionsParams"]


class ActionAcceptSuggestionsParams(TypedDict, total=False):
    id: str
    """The ID of the address."""
