# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["AvailableService"]

AvailableService: TypeAlias = Literal["cloud_vpn", "private_wireless_gateway", "virtual_cross_connect"]
